login_resp = {'Access-Control-Allow-Credentials': 'true', 'Access-Control-Allow-Origin': 'https://manage.mist.com', 'Access-Control-Expose-Headers': 'X-CSRFTOKEN,X-Requested-With,X-Page-Page,X-Page-Total', 'Allow': 'OPTIONS, POST', 'Cache-Control': 'no-cache, no-store', 'Content-Type': 'application/json', 'Date': 'Wed, 18 Mar 2020 14:23:11 GMT', 'Pragma': 'no-cache', 'Server': 'gunicorn/19.10.0', 'Set-Cookie': 'csrftoken=MoMzPM3ZGAYbEahsuCx1CviRPbBtQXE8; Domain=.mist.com; expires=Wed, 17-Mar-2021 14:23:11 GMT; Max-Age=31449600; Path=/; Secure, sessionid=35l5sucjl4agnhza7eyuvec10sj53ar0; Domain=.mist.com; expires=Wed, 01-Apr-2020 14:23:11 GMT; HttpOnly; Max-Age=1209600; Path=/; Secure', 'Vary': 'Origin', 'Via': 'kong/0.9.3', 'X-Frame-Options': 'SAMEORIGIN', 'X-Kong-Proxy-Latency': '0', 'X-Kong-Upstream-Latency': '44', 'Content-Length': '2', 'Connection': 'keep-alive'}